You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@bigtop.apache.org by rv...@apache.org on 2017/03/23 17:28:21 UTC

[50/50] [abbrv] bigtop git commit: BIGTOP-2704. Include ODPi runtime tests option into the battery of smoke tests

BIGTOP-2704. Include ODPi runtime tests option into the battery of smoke tests

Updating namespaces to reflect ODPi -> Bigtop transition


Project: http://git-wip-us.apache.org/repos/asf/bigtop/repo
Commit: http://git-wip-us.apache.org/repos/asf/bigtop/commit/0f51fb32
Tree: http://git-wip-us.apache.org/repos/asf/bigtop/tree/0f51fb32
Diff: http://git-wip-us.apache.org/repos/asf/bigtop/diff/0f51fb32

Branch: refs/heads/master
Commit: 0f51fb32531daa6c0b66e6bbd8fc9813023019ba
Parents: c66106b
Author: Roman Shaposhnik <rv...@apache.org>
Authored: Wed Mar 22 09:37:47 2017 -0700
Committer: Roman Shaposhnik <rv...@apache.org>
Committed: Thu Mar 23 10:27:17 2017 -0700

----------------------------------------------------------------------
 .../smoke-tests/odpi-runtime/build.gradle       |  4 +-
 .../odpi/specs/runtime/hadoop/ApiExaminer.java  |  2 +-
 .../org/odpi/specs/runtime/hive/HCatalogMR.java |  8 +-
 .../src/main/resources/api-examiner-prep.sh     |  4 +-
 .../odpi/specs/runtime/TestSpecsRuntime.groovy  |  6 +-
 .../org/odpi/specs/runtime/hive/HiveHelper.java |  2 +-
 .../odpi/specs/runtime/hive/JdbcConnector.java  | 20 ++--
 .../odpi/specs/runtime/hive/TestBeeline.java    | 55 +++++------
 .../org/odpi/specs/runtime/hive/TestCLI.java    | 96 ++++++++++----------
 .../odpi/specs/runtime/hive/TestHCatalog.java   | 10 +-
 .../org/odpi/specs/runtime/hive/TestJdbc.java   | 10 +-
 .../org/odpi/specs/runtime/hive/TestSql.java    | 36 ++++----
 .../org/odpi/specs/runtime/hive/TestThrift.java | 12 +--
 13 files changed, 133 insertions(+), 132 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/bigtop/blob/0f51fb32/bigtop-tests/smoke-tests/odpi-runtime/build.gradle
----------------------------------------------------------------------
diff --git a/bigtop-tests/smoke-tests/odpi-runtime/build.gradle b/bigtop-tests/smoke-tests/odpi-runtime/build.gradle
index 1b9558c..6132734 100644
--- a/bigtop-tests/smoke-tests/odpi-runtime/build.gradle
+++ b/bigtop-tests/smoke-tests/odpi-runtime/build.gradle
@@ -57,7 +57,7 @@ jar {
 test {
   // Change the default location where test data is picked up
   systemProperty 'test.resources.dir', "${buildDir}/resources/test/"
-  systemProperty 'odpi.test.hive.hcat.job.jar', jar.archivePath
-  systemProperty 'odpi.test.hive.hcat.core.jar', (configurations.runtime).find { it.toString() =~ /hive-hcatalog-core-.*jar$/ }
+  systemProperty 'bigtop.test.hive.hcat.job.jar', jar.archivePath
+  systemProperty 'bigtop.test.hive.hcat.core.jar', (configurations.runtime).find { it.toString() =~ /hive-hcatalog-core-.*jar$/ }
 }
 test.dependsOn jar

http://git-wip-us.apache.org/repos/asf/bigtop/blob/0f51fb32/bigtop-tests/smoke-tests/odpi-runtime/src/main/java/org/odpi/specs/runtime/hadoop/ApiExaminer.java
----------------------------------------------------------------------
diff --git a/bigtop-tests/smoke-tests/odpi-runtime/src/main/java/org/odpi/specs/runtime/hadoop/ApiExaminer.java b/bigtop-tests/smoke-tests/odpi-runtime/src/main/java/org/odpi/specs/runtime/hadoop/ApiExaminer.java
index 05d0eae..a8febdb 100644
--- a/bigtop-tests/smoke-tests/odpi-runtime/src/main/java/org/odpi/specs/runtime/hadoop/ApiExaminer.java
+++ b/bigtop-tests/smoke-tests/odpi-runtime/src/main/java/org/odpi/specs/runtime/hadoop/ApiExaminer.java
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.odpi.specs.runtime.hadoop;
+package org.apache.bigtop.itest.hadoop.api;
 
 import org.apache.commons.cli.CommandLine;
 import org.apache.commons.cli.GnuParser;

http://git-wip-us.apache.org/repos/asf/bigtop/blob/0f51fb32/bigtop-tests/smoke-tests/odpi-runtime/src/main/java/org/odpi/specs/runtime/hive/HCatalogMR.java
----------------------------------------------------------------------
diff --git a/bigtop-tests/smoke-tests/odpi-runtime/src/main/java/org/odpi/specs/runtime/hive/HCatalogMR.java b/bigtop-tests/smoke-tests/odpi-runtime/src/main/java/org/odpi/specs/runtime/hive/HCatalogMR.java
index 2091e34..6456cf2 100644
--- a/bigtop-tests/smoke-tests/odpi-runtime/src/main/java/org/odpi/specs/runtime/hive/HCatalogMR.java
+++ b/bigtop-tests/smoke-tests/odpi-runtime/src/main/java/org/odpi/specs/runtime/hive/HCatalogMR.java
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.odpi.specs.runtime.hive;
+package org.apache.bigtop.itest.hive;
 
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.conf.Configured;
@@ -41,8 +41,8 @@ import java.net.URI;
 import java.util.StringTokenizer;
 
 public class HCatalogMR extends Configured implements Tool {
-  private final static String INPUT_SCHEMA = "odpi.test.hcat.schema.input";
-  private final static String OUTPUT_SCHEMA = "odpi.test.hcat.schema.output";
+  private final static String INPUT_SCHEMA = "bigtop.test.hcat.schema.input";
+  private final static String OUTPUT_SCHEMA = "bigtop.test.hcat.schema.output";
 
   @Override
   public int run(String[] args) throws Exception {
@@ -68,7 +68,7 @@ public class HCatalogMR extends Configured implements Tool {
     conf.set(INPUT_SCHEMA, inputSchemaStr);
     conf.set(OUTPUT_SCHEMA, outputSchemaStr);
 
-    Job job = new Job(conf, "odpi_hcat_test");
+    Job job = new Job(conf, "bigtop_hcat_test");
     HCatInputFormat.setInput(job, "default", inputTable);
 
     job.setInputFormatClass(HCatInputFormat.class);

http://git-wip-us.apache.org/repos/asf/bigtop/blob/0f51fb32/bigtop-tests/smoke-tests/odpi-runtime/src/main/resources/api-examiner-prep.sh
----------------------------------------------------------------------
diff --git a/bigtop-tests/smoke-tests/odpi-runtime/src/test/groovy/org/odpi/specs/runtime/TestSpecsRuntime.groovy b/bigtop-tests/smoke-tests/odpi-runtime/src/test/groovy/org/odpi/specs/runtime/TestSpecsRuntime.groovy
index 46bdbed..60d869c 100644
--- a/bigtop-tests/smoke-tests/odpi-runtime/src/test/groovy/org/odpi/specs/runtime/TestSpecsRuntime.groovy
+++ b/bigtop-tests/smoke-tests/odpi-runtime/src/test/groovy/org/odpi/specs/runtime/TestSpecsRuntime.groovy
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.odpi.specs.runtime
+package org.apache.bigtop.itest.hadoop.odpi 
 
 import groovy.io.FileType
 import org.junit.Assert
@@ -256,10 +256,10 @@ public class TestSpecsRuntime {
         Assert.assertEquals("Expected only one jar, but got " + jars.join(", "), 1, jars.length)
         def jar = dir.getAbsolutePath() + "/" + jars[0]
 
-        def examinerJar = System.properties['odpi.test.hive.hcat.job.jar']
+        def examinerJar = System.properties['bigtop.test.hive.hcat.job.jar']
         def resourceFile = System.properties['test.resources.dir']+ "/" + arguments['resourceFile']
         Shell sh = new Shell()
-        def results = sh.exec("hadoop jar " + examinerJar + " org.odpi.specs.runtime.hadoop.ApiExaminer -c " + resourceFile + " -j " + jar).getErr()
+        def results = sh.exec("hadoop jar " + examinerJar + " org.apache.bigtop.itest.hadoop.api.ApiExaminer -c " + resourceFile + " -j " + jar).getErr()
         int rc = sh.getRet()
         Assert.assertEquals("Expected command to succeed, but got return code " + rc, 0, rc)
         if (results.size() > 0) {

http://git-wip-us.apache.org/repos/asf/bigtop/blob/0f51fb32/bigtop-tests/smoke-tests/odpi-runtime/src/test/java/org/odpi/specs/runtime/hive/HiveHelper.java
----------------------------------------------------------------------
diff --git a/bigtop-tests/smoke-tests/odpi-runtime/src/test/java/org/odpi/specs/runtime/hive/HiveHelper.java b/bigtop-tests/smoke-tests/odpi-runtime/src/test/java/org/odpi/specs/runtime/hive/HiveHelper.java
index 72d34c7..ee20588 100644
--- a/bigtop-tests/smoke-tests/odpi-runtime/src/test/java/org/odpi/specs/runtime/hive/HiveHelper.java
+++ b/bigtop-tests/smoke-tests/odpi-runtime/src/test/java/org/odpi/specs/runtime/hive/HiveHelper.java
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.odpi.specs.runtime.hive;
+package org.apache.bigtop.itest.hive;
 
 import java.io.ByteArrayOutputStream;
 import java.io.IOException;

http://git-wip-us.apache.org/repos/asf/bigtop/blob/0f51fb32/bigtop-tests/smoke-tests/odpi-runtime/src/test/java/org/odpi/specs/runtime/hive/JdbcConnector.java
----------------------------------------------------------------------
diff --git a/bigtop-tests/smoke-tests/odpi-runtime/src/test/java/org/odpi/specs/runtime/hive/JdbcConnector.java b/bigtop-tests/smoke-tests/odpi-runtime/src/test/java/org/odpi/specs/runtime/hive/JdbcConnector.java
index 095eb54..3b3ac51 100644
--- a/bigtop-tests/smoke-tests/odpi-runtime/src/test/java/org/odpi/specs/runtime/hive/JdbcConnector.java
+++ b/bigtop-tests/smoke-tests/odpi-runtime/src/test/java/org/odpi/specs/runtime/hive/JdbcConnector.java
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.odpi.specs.runtime.hive;
+package org.apache.bigtop.itest.hive;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -30,15 +30,15 @@ import java.util.Properties;
 public class JdbcConnector {
   private static final Log LOG = LogFactory.getLog(JdbcConnector.class.getName());
 
-  protected static final String URL = "odpi.test.hive.jdbc.url";
-  protected static final String USER = "odpi.test.hive.jdbc.user";
-  protected static final String PASSWD = "odpi.test.hive.jdbc.password";
-  protected static final String LOCATION = "odpi.test.hive.location";
-  protected static final String METASTORE_URL = "odpi.test.hive.metastore.url";
-  protected static final String TEST_THRIFT = "odpi.test.hive.thrift.test";
-  protected static final String TEST_HCATALOG = "odpi.test.hive.hcatalog.test";
-  protected static final String HIVE_CONF_DIR = "odpi.test.hive.conf.dir";
-  protected static final String HADOOP_CONF_DIR = "odpi.test.hadoop.conf.dir";
+  protected static final String URL = "bigtop.test.hive.jdbc.url";
+  protected static final String USER = "bigtop.test.hive.jdbc.user";
+  protected static final String PASSWD = "bigtop.test.hive.jdbc.password";
+  protected static final String LOCATION = "bigtop.test.hive.location";
+  protected static final String METASTORE_URL = "bigtop.test.hive.metastore.url";
+  protected static final String TEST_THRIFT = "bigtop.test.hive.thrift.test";
+  protected static final String TEST_HCATALOG = "bigtop.test.hive.hcatalog.test";
+  protected static final String HIVE_CONF_DIR = "bigtop.test.hive.conf.dir";
+  protected static final String HADOOP_CONF_DIR = "bigtop.test.hadoop.conf.dir";
 
   protected static Connection conn;
 

http://git-wip-us.apache.org/repos/asf/bigtop/blob/0f51fb32/bigtop-tests/smoke-tests/odpi-runtime/src/test/java/org/odpi/specs/runtime/hive/TestBeeline.java
----------------------------------------------------------------------
diff --git a/bigtop-tests/smoke-tests/odpi-runtime/src/test/java/org/odpi/specs/runtime/hive/TestBeeline.java b/bigtop-tests/smoke-tests/odpi-runtime/src/test/java/org/odpi/specs/runtime/hive/TestBeeline.java
index 5e6e89c..bc2ab77 100644
--- a/bigtop-tests/smoke-tests/odpi-runtime/src/test/java/org/odpi/specs/runtime/hive/TestBeeline.java
+++ b/bigtop-tests/smoke-tests/odpi-runtime/src/test/java/org/odpi/specs/runtime/hive/TestBeeline.java
@@ -15,7 +15,8 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.odpi.specs.runtime.hive;
+package org.apache.bigtop.itest.hive;
+
 import org.apache.commons.exec.CommandLine;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -31,9 +32,9 @@ public class TestBeeline {
 	
 	public static final Log LOG = LogFactory.getLog(TestBeeline.class.getName());
 	
-	private static final String URL = "odpi.test.hive.jdbc.url";
-	private static final String USER = "odpi.test.hive.jdbc.user";
-	private static final String PASSWD = "odpi.test.hive.jdbc.password";
+	private static final String URL = "bigtop.test.hive.jdbc.url";
+	private static final String USER = "bigtop.test.hive.jdbc.user";
+	private static final String PASSWD = "bigtop.test.hive.jdbc.password";
 	
 	private static Map<String, String> results;
 	private static String beelineUrl; 
@@ -94,29 +95,29 @@ public class TestBeeline {
 	@Test
 	public void checkBeelineQueryExecFromCmdLine(){
 		results = HiveHelper.execCommand(new CommandLine(beelineBaseCommand).addArgument("-e").addArgument("SHOW DATABASES;"));
-		if(!results.get("outputStream").contains("odpi_runtime_hive")){
-			results = HiveHelper.execCommand(new CommandLine(beelineBaseCommand).addArgument("-e").addArgument("CREATE DATABASE odpi_runtime_hive;"));
+		if(!results.get("outputStream").contains("bigtop_runtime_hive")){
+			results = HiveHelper.execCommand(new CommandLine(beelineBaseCommand).addArgument("-e").addArgument("CREATE DATABASE bigtop_runtime_hive;"));
 			results = HiveHelper.execCommand(new CommandLine(beelineBaseCommand).addArgument("-e").addArgument("SHOW DATABASES;"));
 		}else{
-			results = HiveHelper.execCommand(new CommandLine(beelineBaseCommand).addArgument("-e").addArgument("DROP DATABASE odpi_runtime_hive;"));
-			results = HiveHelper.execCommand(new CommandLine(beelineBaseCommand).addArgument("-e").addArgument("CREATE DATABASE odpi_runtime_hive;"));
+			results = HiveHelper.execCommand(new CommandLine(beelineBaseCommand).addArgument("-e").addArgument("DROP DATABASE bigtop_runtime_hive;"));
+			results = HiveHelper.execCommand(new CommandLine(beelineBaseCommand).addArgument("-e").addArgument("CREATE DATABASE bigtop_runtime_hive;"));
 			results = HiveHelper.execCommand(new CommandLine(beelineBaseCommand).addArgument("-e").addArgument("SHOW DATABASES;"));
 		}
 		String consoleMsg = results.get("outputStream").toLowerCase();
-		Assert.assertEquals("beeline -e FAILED. \n" +results.get("outputStream"), true, consoleMsg.contains("odpi_runtime_hive" ) && !consoleMsg.contains("error") && !consoleMsg.contains("exception"));
-		HiveHelper.execCommand(new CommandLine(beelineBaseCommand).addArgument("-e").addArgument("DROP DATABASE odpi_runtime_hive"));
+		Assert.assertEquals("beeline -e FAILED. \n" +results.get("outputStream"), true, consoleMsg.contains("bigtop_runtime_hive" ) && !consoleMsg.contains("error") && !consoleMsg.contains("exception"));
+		HiveHelper.execCommand(new CommandLine(beelineBaseCommand).addArgument("-e").addArgument("DROP DATABASE bigtop_runtime_hive"));
 	}
 	
 	@Test
 	public void checkBeelineQueryExecFromFile() throws FileNotFoundException{
 		
 		try(PrintWriter out = new PrintWriter("beeline-f1.sql")){ out.println("SHOW DATABASES;"); }
-		try(PrintWriter out = new PrintWriter("beeline-f2.sql")){ out.println("CREATE DATABASE odpi_runtime_hive;"); }
-		try(PrintWriter out = new PrintWriter("beeline-f3.sql")){ out.println("DROP DATABASE odpi_runtime_hive;"); out.println("CREATE DATABASE odpi_runtime_hive;"); }
-		try(PrintWriter out = new PrintWriter("beeline-f4.sql")){ out.println("DROP DATABASE odpi_runtime_hive;"); }
+		try(PrintWriter out = new PrintWriter("beeline-f2.sql")){ out.println("CREATE DATABASE bigtop_runtime_hive;"); }
+		try(PrintWriter out = new PrintWriter("beeline-f3.sql")){ out.println("DROP DATABASE bigtop_runtime_hive;"); out.println("CREATE DATABASE bigtop_runtime_hive;"); }
+		try(PrintWriter out = new PrintWriter("beeline-f4.sql")){ out.println("DROP DATABASE bigtop_runtime_hive;"); }
 		results = HiveHelper.execCommand(new CommandLine(beelineBaseCommand).addArgument("-f").addArgument("beeline-f1.sql",false));
 		
-		if(!results.get("outputStream").contains("odpi_runtime_hive")){
+		if(!results.get("outputStream").contains("bigtop_runtime_hive")){
 			results = HiveHelper.execCommand(new CommandLine(beelineBaseCommand).addArgument("-f").addArgument("beeline-f2.sql",false));
 		}else{
 			results = HiveHelper.execCommand(new CommandLine(beelineBaseCommand).addArgument("-f").addArgument("beeline-f3.sql",false));
@@ -125,7 +126,7 @@ public class TestBeeline {
 		results = HiveHelper.execCommand(new CommandLine(beelineBaseCommand).addArgument("-f").addArgument("beeline-f1.sql",false));
 
 		String consoleMsg = results.get("outputStream").toLowerCase();
-		Assert.assertEquals("beeline -f FAILED. \n" +results.get("outputStream"), true, consoleMsg.contains("odpi_runtime_hive" ) && !consoleMsg.contains("error") && !consoleMsg.contains("exception"));
+		Assert.assertEquals("beeline -f FAILED. \n" +results.get("outputStream"), true, consoleMsg.contains("bigtop_runtime_hive" ) && !consoleMsg.contains("error") && !consoleMsg.contains("exception"));
 		HiveHelper.execCommand(new CommandLine(beelineBaseCommand).addArgument("-f").addArgument("beeline-f4.sql",false));	
 	}
 	
@@ -133,12 +134,12 @@ public class TestBeeline {
 	public void checkBeelineInitFile() throws FileNotFoundException{
 
 		try(PrintWriter out = new PrintWriter("beeline-i1.sql")){ out.println("SHOW DATABASES;"); }
-		try(PrintWriter out = new PrintWriter("beeline-i2.sql")){ out.println("CREATE DATABASE odpi_runtime_beeline_init;"); }
-		try(PrintWriter out = new PrintWriter("beeline-i3.sql")){ out.println("DROP DATABASE odpi_runtime_beeline_init;"); out.println("CREATE DATABASE odpi_runtime_beeline_init;"); }
-		try(PrintWriter out = new PrintWriter("beeline-i4.sql")){ out.println("DROP DATABASE odpi_runtime_beeline_init;"); }
+		try(PrintWriter out = new PrintWriter("beeline-i2.sql")){ out.println("CREATE DATABASE bigtop_runtime_beeline_init;"); }
+		try(PrintWriter out = new PrintWriter("beeline-i3.sql")){ out.println("DROP DATABASE bigtop_runtime_beeline_init;"); out.println("CREATE DATABASE bigtop_runtime_beeline_init;"); }
+		try(PrintWriter out = new PrintWriter("beeline-i4.sql")){ out.println("DROP DATABASE bigtop_runtime_beeline_init;"); }
 		results = HiveHelper.execCommand(new CommandLine(beelineBaseCommand).addArgument("-i").addArgument("beeline-i1.sql",false));
 	
-		if(!results.get("outputStream").contains("odpi_runtime_beeline_init")){
+		if(!results.get("outputStream").contains("bigtop_runtime_beeline_init")){
 			results = HiveHelper.execCommand(new CommandLine(beelineBaseCommand).addArgument("-i").addArgument("beeline-i2.sql",false));
 		}else{
 			results = HiveHelper.execCommand(new CommandLine(beelineBaseCommand).addArgument("-i").addArgument("beeline-i3.sql",false));
@@ -146,7 +147,7 @@ public class TestBeeline {
 		
 		results = HiveHelper.execCommand(new CommandLine(beelineBaseCommand).addArgument("-i").addArgument("beeline-i1.sql",false));
 		String consoleMsg = results.get("outputStream").toLowerCase();
-		Assert.assertEquals("beeline -i FAILED. \n" +results.get("outputStream"), true, consoleMsg.contains("odpi_runtime_beeline_init") && !consoleMsg.contains("error") && !consoleMsg.contains("exception"));
+		Assert.assertEquals("beeline -i FAILED. \n" +results.get("outputStream"), true, consoleMsg.contains("bigtop_runtime_beeline_init") && !consoleMsg.contains("error") && !consoleMsg.contains("exception"));
 		HiveHelper.execCommand(new CommandLine(beelineBaseCommand).addArgument("-i").addArgument("beeline-i4.sql",false));	
 	}
 	
@@ -157,18 +158,18 @@ public class TestBeeline {
 		try(PrintWriter out = new PrintWriter("beeline-hv2.sql")){ out.println("CREATE DATABASE ${db};"); }
 		try(PrintWriter out = new PrintWriter("beeline-hv3.sql")){ out.println("DROP DATABASE ${db};"); out.println("CREATE DATABASE ${db};"); }
 		try(PrintWriter out = new PrintWriter("beeline-hv4.sql")){ out.println("DROP DATABASE ${db};"); }
-		results = HiveHelper.execCommand(new CommandLine(beelineBaseCommand).addArgument("--hivevar").addArgument("db=odpi_runtime_beeline_hivevar").addArgument("-i").addArgument("beeline-hv1.sql",false));
+		results = HiveHelper.execCommand(new CommandLine(beelineBaseCommand).addArgument("--hivevar").addArgument("db=bigtop_runtime_beeline_hivevar").addArgument("-i").addArgument("beeline-hv1.sql",false));
 	
-		if(!results.get("outputStream").contains("odpi_runtime_beeline_hivevar")){
-			results = HiveHelper.execCommand(new CommandLine(beelineBaseCommand).addArgument("--hivevar").addArgument("db=odpi_runtime_beeline_hivevar").addArgument("-i").addArgument("beeline-hv2.sql",false));
+		if(!results.get("outputStream").contains("bigtop_runtime_beeline_hivevar")){
+			results = HiveHelper.execCommand(new CommandLine(beelineBaseCommand).addArgument("--hivevar").addArgument("db=bigtop_runtime_beeline_hivevar").addArgument("-i").addArgument("beeline-hv2.sql",false));
 		}else{
-			results = HiveHelper.execCommand(new CommandLine(beelineBaseCommand).addArgument("--hivevar").addArgument("db=odpi_runtime_beeline_hivevar").addArgument("-i").addArgument("beeline-hv3.sql",false));
+			results = HiveHelper.execCommand(new CommandLine(beelineBaseCommand).addArgument("--hivevar").addArgument("db=bigtop_runtime_beeline_hivevar").addArgument("-i").addArgument("beeline-hv3.sql",false));
 		}
 		
-		results = HiveHelper.execCommand(new CommandLine(beelineBaseCommand).addArgument("--hivevar").addArgument("db=odpi_runtime_beeline_hivevar").addArgument("-i").addArgument("beeline-hv1.sql",false));
+		results = HiveHelper.execCommand(new CommandLine(beelineBaseCommand).addArgument("--hivevar").addArgument("db=bigtop_runtime_beeline_hivevar").addArgument("-i").addArgument("beeline-hv1.sql",false));
 		String consoleMsg = results.get("outputStream").toLowerCase();
-		Assert.assertEquals("beeline --hivevar FAILED. \n" +results.get("outputStream"), true, consoleMsg.contains("odpi_runtime_beeline_hivevar") && !consoleMsg.contains("error") && !consoleMsg.contains("exception"));
-		HiveHelper.execCommand(new CommandLine(beelineBaseCommand).addArgument("--hivevar").addArgument("db=odpi_runtime_beeline_hivevar").addArgument("-i").addArgument("beeline-hv4.sql",false));		 
+		Assert.assertEquals("beeline --hivevar FAILED. \n" +results.get("outputStream"), true, consoleMsg.contains("bigtop_runtime_beeline_hivevar") && !consoleMsg.contains("error") && !consoleMsg.contains("exception"));
+		HiveHelper.execCommand(new CommandLine(beelineBaseCommand).addArgument("--hivevar").addArgument("db=bigtop_runtime_beeline_hivevar").addArgument("-i").addArgument("beeline-hv4.sql",false));		 
 	}
 	
 	@Test

http://git-wip-us.apache.org/repos/asf/bigtop/blob/0f51fb32/bigtop-tests/smoke-tests/odpi-runtime/src/test/java/org/odpi/specs/runtime/hive/TestCLI.java
----------------------------------------------------------------------
diff --git a/bigtop-tests/smoke-tests/odpi-runtime/src/test/java/org/odpi/specs/runtime/hive/TestCLI.java b/bigtop-tests/smoke-tests/odpi-runtime/src/test/java/org/odpi/specs/runtime/hive/TestCLI.java
index 61bb9ac..c55bb92 100644
--- a/bigtop-tests/smoke-tests/odpi-runtime/src/test/java/org/odpi/specs/runtime/hive/TestCLI.java
+++ b/bigtop-tests/smoke-tests/odpi-runtime/src/test/java/org/odpi/specs/runtime/hive/TestCLI.java
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.odpi.specs.runtime.hive;
+package org.apache.bigtop.itest.hive;
 
 import java.io.FileNotFoundException;
 import java.io.PrintWriter;
@@ -30,7 +30,7 @@ import org.junit.Assert;
 public class TestCLI {
 	
 	static Map<String, String> results;
-	static String db = "javax.jdo.option.ConnectionURL=jdbc:derby:;databaseName=odpi_metastore_db;create=true";
+	static String db = "javax.jdo.option.ConnectionURL=jdbc:derby:;databaseName=bigtop_metastore_db;create=true";
 	
 	@BeforeClass
 	public static void setup(){
@@ -57,31 +57,31 @@ public class TestCLI {
 		
 		results = HiveHelper.execCommand(new CommandLine("hive").addArgument("-e").addArgument("SHOW DATABASES").addArgument("--hiveconf").addArgument(db));
 		Assert.assertEquals("SHOW DATABASES command failed to execute.", 0, Integer.parseInt(results.get("exitValue")));
-		if(!results.get("outputStream").contains("odpi_runtime_hive")){
-			results = HiveHelper.execCommand(new CommandLine("hive").addArgument("-e").addArgument("CREATE DATABASE odpi_runtime_hive").addArgument("--hiveconf").addArgument(db));
-			Assert.assertEquals("Could not create database odpi_runtime_hive.", 0, Integer.parseInt(results.get("exitValue")));
+		if(!results.get("outputStream").contains("bigtop_runtime_hive")){
+			results = HiveHelper.execCommand(new CommandLine("hive").addArgument("-e").addArgument("CREATE DATABASE bigtop_runtime_hive").addArgument("--hiveconf").addArgument(db));
+			Assert.assertEquals("Could not create database bigtop_runtime_hive.", 0, Integer.parseInt(results.get("exitValue")));
 		}else{
-			results = HiveHelper.execCommand(new CommandLine("hive").addArgument("-e").addArgument("DROP DATABASE odpi_runtime_hive").addArgument("--hiveconf").addArgument(db));
-			results = HiveHelper.execCommand(new CommandLine("hive").addArgument("-e").addArgument("CREATE DATABASE odpi_runtime_hive").addArgument("--hiveconf").addArgument(db));
-			Assert.assertEquals("Could not create database odpi_runtime_hive.", 0, Integer.parseInt(results.get("exitValue")));
+			results = HiveHelper.execCommand(new CommandLine("hive").addArgument("-e").addArgument("DROP DATABASE bigtop_runtime_hive").addArgument("--hiveconf").addArgument(db));
+			results = HiveHelper.execCommand(new CommandLine("hive").addArgument("-e").addArgument("CREATE DATABASE bigtop_runtime_hive").addArgument("--hiveconf").addArgument(db));
+			Assert.assertEquals("Could not create database bigtop_runtime_hive.", 0, Integer.parseInt(results.get("exitValue")));
 		}
-		results = HiveHelper.execCommand(new CommandLine("hive").addArgument("-e").addArgument("DROP DATABASE odpi_runtime_hive").addArgument("--hiveconf").addArgument(db));
+		results = HiveHelper.execCommand(new CommandLine("hive").addArgument("-e").addArgument("DROP DATABASE bigtop_runtime_hive").addArgument("--hiveconf").addArgument(db));
 	}
 	
 	@Test
 	public void sqlFromFiles() throws FileNotFoundException{
 		try(PrintWriter out = new PrintWriter("hive-f1.sql")){ out.println("SHOW DATABASES;"); }
-		try(PrintWriter out = new PrintWriter("hive-f2.sql")){ out.println("CREATE DATABASE odpi_runtime_hive;"); }
-		try(PrintWriter out = new PrintWriter("hive-f3.sql")){ out.println("DROP DATABASE odpi_runtime_hive;"); out.println("CREATE DATABASE odpi_runtime_hive;"); }
-		try(PrintWriter out = new PrintWriter("hive-f4.sql")){ out.println("DROP DATABASE odpi_runtime_hive;"); }
+		try(PrintWriter out = new PrintWriter("hive-f2.sql")){ out.println("CREATE DATABASE bigtop_runtime_hive;"); }
+		try(PrintWriter out = new PrintWriter("hive-f3.sql")){ out.println("DROP DATABASE bigtop_runtime_hive;"); out.println("CREATE DATABASE bigtop_runtime_hive;"); }
+		try(PrintWriter out = new PrintWriter("hive-f4.sql")){ out.println("DROP DATABASE bigtop_runtime_hive;"); }
 		results = HiveHelper.execCommand(new CommandLine("hive").addArgument("-f").addArgument("hive-f1.sql").addArgument("--hiveconf").addArgument(db));
 		Assert.assertEquals("SHOW DATABASES command failed to execute.", 0, Integer.parseInt(results.get("exitValue")));
-		if(!results.get("outputStream").contains("odpi_runtime_hive")){
+		if(!results.get("outputStream").contains("bigtop_runtime_hive")){
 			results = HiveHelper.execCommand(new CommandLine("hive").addArgument("-f").addArgument("hive-f2.sql").addArgument("--hiveconf").addArgument(db));
-			Assert.assertEquals("Could not create database odpi_runtime_hive.", 0, Integer.parseInt(results.get("exitValue")));
+			Assert.assertEquals("Could not create database bigtop_runtime_hive.", 0, Integer.parseInt(results.get("exitValue")));
 		}else{
 			results = HiveHelper.execCommand(new CommandLine("hive").addArgument("-f").addArgument("hive-f3.sql").addArgument("--hiveconf").addArgument(db));
-			Assert.assertEquals("Could not create database odpi_runtime_hive.", 0, Integer.parseInt(results.get("exitValue")));
+			Assert.assertEquals("Could not create database bigtop_runtime_hive.", 0, Integer.parseInt(results.get("exitValue")));
 		}
 		results = HiveHelper.execCommand(new CommandLine("hive").addArgument("-f").addArgument("hive-f4.sql").addArgument("--hiveconf").addArgument(db));
 	}
@@ -106,46 +106,46 @@ public class TestCLI {
 	
 	@Test
 	public void initialization() throws FileNotFoundException{
-		try(PrintWriter out = new PrintWriter("hive-init1.sql")){ out.println("CREATE DATABASE odpi_runtime_hive;"); }
-		try(PrintWriter out = new PrintWriter("hive-init2.sql")){ out.println("DROP DATABASE odpi_runtime_hive;"); out.println("CREATE DATABASE odpi_runtime_hive;"); }
+		try(PrintWriter out = new PrintWriter("hive-init1.sql")){ out.println("CREATE DATABASE bigtop_runtime_hive;"); }
+		try(PrintWriter out = new PrintWriter("hive-init2.sql")){ out.println("DROP DATABASE bigtop_runtime_hive;"); out.println("CREATE DATABASE bigtop_runtime_hive;"); }
 		
 		results = HiveHelper.execCommand(new CommandLine("hive").addArgument("-e").addArgument("SHOW DATABASES").addArgument("--hiveconf").addArgument(db));
 		Assert.assertEquals("SHOW DATABASES command failed to execute.", 0, Integer.parseInt(results.get("exitValue")));
-		if(!results.get("outputStream").contains("odpi_runtime_hive")){
+		if(!results.get("outputStream").contains("bigtop_runtime_hive")){
 			results = HiveHelper.execCommand(new CommandLine("hive").addArgument("-i").addArgument("hive-init1.sql").addArgument("-e").addArgument("SHOW DATABASES").addArgument("--hiveconf").addArgument(db));
-			Assert.assertEquals("Could not create database odpi_runtime_hive using the init -i option.", 0, Integer.parseInt(results.get("exitValue")));
-			Assert.assertEquals("Could not create database odpi_runtime_hive using the init -i option.", true, results.get("outputStream").contains("odpi_runtime_hive"));
+			Assert.assertEquals("Could not create database bigtop_runtime_hive using the init -i option.", 0, Integer.parseInt(results.get("exitValue")));
+			Assert.assertEquals("Could not create database bigtop_runtime_hive using the init -i option.", true, results.get("outputStream").contains("bigtop_runtime_hive"));
 		}else{
 			results = HiveHelper.execCommand(new CommandLine("hive").addArgument("-i").addArgument("hive-init2.sql").addArgument("-e").addArgument("SHOW DATABASES").addArgument("--hiveconf").addArgument(db));
-			Assert.assertEquals("Could not create database odpi_runtime_hive.", 0, Integer.parseInt(results.get("exitValue")));
-			Assert.assertEquals("Could not create database odpi_runtime_hive using the init -i option.", true, results.get("outputStream").contains("odpi_runtime_hive"));
+			Assert.assertEquals("Could not create database bigtop_runtime_hive.", 0, Integer.parseInt(results.get("exitValue")));
+			Assert.assertEquals("Could not create database bigtop_runtime_hive using the init -i option.", true, results.get("outputStream").contains("bigtop_runtime_hive"));
 		}
-		results = HiveHelper.execCommand(new CommandLine("hive").addArgument("-e").addArgument("DROP DATABASE odpi_runtime_hive").addArgument("--hiveconf").addArgument(db));
+		results = HiveHelper.execCommand(new CommandLine("hive").addArgument("-e").addArgument("DROP DATABASE bigtop_runtime_hive").addArgument("--hiveconf").addArgument(db));
 	}
 	
 	@Test
 	public void database(){
 		
 		results = HiveHelper.execCommand(new CommandLine("hive").addArgument("-e").addArgument("SHOW DATABASES").addArgument("--hiveconf").addArgument(db));
-		if(!results.get("outputStream").contains("odpi_runtime_hive")){
-			results = HiveHelper.execCommand(new CommandLine("hive").addArgument("-e").addArgument("CREATE DATABASE odpi_runtime_hive").addArgument("--hiveconf").addArgument(db));
+		if(!results.get("outputStream").contains("bigtop_runtime_hive")){
+			results = HiveHelper.execCommand(new CommandLine("hive").addArgument("-e").addArgument("CREATE DATABASE bigtop_runtime_hive").addArgument("--hiveconf").addArgument(db));
 		}else{
-			results = HiveHelper.execCommand(new CommandLine("hive").addArgument("-e").addArgument("DROP DATABASE odpi_runtime_hive").addArgument("--hiveconf").addArgument(db));
-			results = HiveHelper.execCommand(new CommandLine("hive").addArgument("-e").addArgument("CREATE DATABASE odpi_runtime_hive").addArgument("--hiveconf").addArgument(db));
+			results = HiveHelper.execCommand(new CommandLine("hive").addArgument("-e").addArgument("DROP DATABASE bigtop_runtime_hive").addArgument("--hiveconf").addArgument(db));
+			results = HiveHelper.execCommand(new CommandLine("hive").addArgument("-e").addArgument("CREATE DATABASE bigtop_runtime_hive").addArgument("--hiveconf").addArgument(db));
 		}
-		results = HiveHelper.execCommand(new CommandLine("hive").addArgument("--database").addArgument("odpi_runtime_hive_1234").addArgument("-e").addArgument("CREATE TABLE odpi ( MYID INT );").addArgument("--hiveconf").addArgument(db));
+		results = HiveHelper.execCommand(new CommandLine("hive").addArgument("--database").addArgument("bigtop_runtime_hive_1234").addArgument("-e").addArgument("CREATE TABLE bigtop ( MYID INT );").addArgument("--hiveconf").addArgument(db));
 		Assert.assertEquals("Non-existent database returned with wrong exit code: "+Integer.parseInt(results.get("exitValue")), 88, Integer.parseInt(results.get("exitValue")));
 		
-		results = HiveHelper.execCommand(new CommandLine("hive").addArgument("--database").addArgument("odpi_runtime_hive").addArgument("-e").addArgument("CREATE TABLE odpi ( MYID INT );").addArgument("--hiveconf").addArgument(db));
+		results = HiveHelper.execCommand(new CommandLine("hive").addArgument("--database").addArgument("bigtop_runtime_hive").addArgument("-e").addArgument("CREATE TABLE bigtop ( MYID INT );").addArgument("--hiveconf").addArgument(db));
 		Assert.assertEquals("Failed to create table using --database argument.", 0, Integer.parseInt(results.get("exitValue")));
 		
-		results = HiveHelper.execCommand(new CommandLine("hive").addArgument("--database").addArgument("odpi_runtime_hive").addArgument("-e").addArgument("DESCRIBE odpi").addArgument("--hiveconf").addArgument(db));
-		Assert.assertEquals("Failed to get expected column after creating odpi table using --database argument.", true, results.get("outputStream").contains("myid"));
+		results = HiveHelper.execCommand(new CommandLine("hive").addArgument("--database").addArgument("bigtop_runtime_hive").addArgument("-e").addArgument("DESCRIBE bigtop").addArgument("--hiveconf").addArgument(db));
+		Assert.assertEquals("Failed to get expected column after creating bigtop table using --database argument.", true, results.get("outputStream").contains("myid"));
 		
-		results = HiveHelper.execCommand(new CommandLine("hive").addArgument("--database").addArgument("odpi_runtime_hive").addArgument("-e").addArgument("DROP TABLE odpi").addArgument("--hiveconf").addArgument(db));
+		results = HiveHelper.execCommand(new CommandLine("hive").addArgument("--database").addArgument("bigtop_runtime_hive").addArgument("-e").addArgument("DROP TABLE bigtop").addArgument("--hiveconf").addArgument(db));
 		Assert.assertEquals("Failed to create table using --database argument.", 0, Integer.parseInt(results.get("exitValue")));
 		
-		results = HiveHelper.execCommand(new CommandLine("hive").addArgument("-e").addArgument("DROP DATABASE odpi_runtime_hive").addArgument("--hiveconf").addArgument(db));
+		results = HiveHelper.execCommand(new CommandLine("hive").addArgument("-e").addArgument("DROP DATABASE bigtop_runtime_hive").addArgument("--hiveconf").addArgument(db));
 	}
 	
 	@Test
@@ -160,49 +160,49 @@ public class TestCLI {
 	@Test
 	public void variableSubsitution() throws FileNotFoundException{
 		results = HiveHelper.execCommand(new CommandLine("hive").addArgument("-e").addArgument("SHOW DATABASES").addArgument("--hiveconf").addArgument(db));
-		if(!results.get("outputStream").contains("odpi_runtime_hive")){
-			results = HiveHelper.execCommand(new CommandLine("hive").addArgument("-e").addArgument("CREATE DATABASE odpi_runtime_hive").addArgument("--hiveconf").addArgument(db));
+		if(!results.get("outputStream").contains("bigtop_runtime_hive")){
+			results = HiveHelper.execCommand(new CommandLine("hive").addArgument("-e").addArgument("CREATE DATABASE bigtop_runtime_hive").addArgument("--hiveconf").addArgument(db));
 		}else{
-			results = HiveHelper.execCommand(new CommandLine("hive").addArgument("-e").addArgument("DROP DATABASE odpi_runtime_hive").addArgument("--hiveconf").addArgument(db));
-			results = HiveHelper.execCommand(new CommandLine("hive").addArgument("-e").addArgument("CREATE DATABASE odpi_runtime_hive").addArgument("--hiveconf").addArgument(db));
+			results = HiveHelper.execCommand(new CommandLine("hive").addArgument("-e").addArgument("DROP DATABASE bigtop_runtime_hive").addArgument("--hiveconf").addArgument(db));
+			results = HiveHelper.execCommand(new CommandLine("hive").addArgument("-e").addArgument("CREATE DATABASE bigtop_runtime_hive").addArgument("--hiveconf").addArgument(db));
 		}
 		try(PrintWriter out = new PrintWriter("hive-define.sql")){ out.println("show ${A};"); out.println("quit;"); }
 		results = HiveHelper.execCommand(new CommandLine("/bin/sh").addArgument("-c").addArgument("hive -d A=DATABASES --hiveconf '"+db+"' < hive-define.sql", false));		
 		Assert.assertEquals("The hive -d A=DATABASES option did not work.", 0, Integer.parseInt(results.get("exitValue")));
-		Assert.assertEquals("The hive -d A=DATABASES option did not work.", true, results.get("outputStream").contains("odpi_runtime_hive"));
+		Assert.assertEquals("The hive -d A=DATABASES option did not work.", true, results.get("outputStream").contains("bigtop_runtime_hive"));
 		
 		results = HiveHelper.execCommand(new CommandLine("/bin/sh").addArgument("-c").addArgument("hive --define A=DATABASES --hiveconf '"+db+"' < hive-define.sql", false));		
 		Assert.assertEquals("The hive --define A=DATABASES option did not work.", 0, Integer.parseInt(results.get("exitValue")));
-		Assert.assertEquals("The hive --define A=DATABASES option did not work.", true, results.get("outputStream").contains("odpi_runtime_hive"));
+		Assert.assertEquals("The hive --define A=DATABASES option did not work.", true, results.get("outputStream").contains("bigtop_runtime_hive"));
 		
-		results = HiveHelper.execCommand(new CommandLine("hive").addArgument("-e").addArgument("DROP DATABASE odpi_runtime_hive").addArgument("--hiveconf").addArgument(db));
+		results = HiveHelper.execCommand(new CommandLine("hive").addArgument("-e").addArgument("DROP DATABASE bigtop_runtime_hive").addArgument("--hiveconf").addArgument(db));
 	}
 	
 	@Test
 	public void hiveVar() throws FileNotFoundException{
 		results = HiveHelper.execCommand(new CommandLine("hive").addArgument("-e").addArgument("SHOW DATABASES").addArgument("--hiveconf").addArgument(db));
-		if(!results.get("outputStream").contains("odpi_runtime_hive")){
-			results = HiveHelper.execCommand(new CommandLine("hive").addArgument("-e").addArgument("CREATE DATABASE odpi_runtime_hive").addArgument("--hiveconf").addArgument(db));
+		if(!results.get("outputStream").contains("bigtop_runtime_hive")){
+			results = HiveHelper.execCommand(new CommandLine("hive").addArgument("-e").addArgument("CREATE DATABASE bigtop_runtime_hive").addArgument("--hiveconf").addArgument(db));
 		}else{
-			results = HiveHelper.execCommand(new CommandLine("hive").addArgument("-e").addArgument("DROP DATABASE odpi_runtime_hive").addArgument("--hiveconf").addArgument(db));
-			results = HiveHelper.execCommand(new CommandLine("hive").addArgument("-e").addArgument("CREATE DATABASE odpi_runtime_hive").addArgument("--hiveconf").addArgument(db));
+			results = HiveHelper.execCommand(new CommandLine("hive").addArgument("-e").addArgument("DROP DATABASE bigtop_runtime_hive").addArgument("--hiveconf").addArgument(db));
+			results = HiveHelper.execCommand(new CommandLine("hive").addArgument("-e").addArgument("CREATE DATABASE bigtop_runtime_hive").addArgument("--hiveconf").addArgument(db));
 		}
 		try(PrintWriter out = new PrintWriter("hive-var.sql")){ out.println("show ${A};"); out.println("quit;"); }
 		results = HiveHelper.execCommand(new CommandLine("/bin/sh").addArgument("-c").addArgument("hive --hivevar A=DATABASES --hiveconf '"+db+"' < hive-var.sql", false));		
 		Assert.assertEquals("The hive --hivevar A=DATABASES option did not work.", 0, Integer.parseInt(results.get("exitValue")));
-		Assert.assertEquals("The hive --hivevar A=DATABASES option did not work.", true, results.get("outputStream").contains("odpi_runtime_hive"));
+		Assert.assertEquals("The hive --hivevar A=DATABASES option did not work.", true, results.get("outputStream").contains("bigtop_runtime_hive"));
 		
 		try(PrintWriter out = new PrintWriter("hiveconf-var.sql")){ out.println("show ${hiveconf:A};"); out.println("quit;"); }
 		results = HiveHelper.execCommand(new CommandLine("/bin/sh").addArgument("-c").addArgument("hive --hiveconf A=DATABASES --hiveconf '"+db+"' < hiveconf-var.sql", false));		
 		Assert.assertEquals("The hive --hiveconf A=DATABASES option did not work.", 0, Integer.parseInt(results.get("exitValue")));
-		Assert.assertEquals("The hive --hiveconf A=DATABASES option did not work.", true, results.get("outputStream").contains("odpi_runtime_hive"));
+		Assert.assertEquals("The hive --hiveconf A=DATABASES option did not work.", true, results.get("outputStream").contains("bigtop_runtime_hive"));
 		
-		results = HiveHelper.execCommand(new CommandLine("hive").addArgument("-e").addArgument("DROP DATABASE odpi_runtime_hive").addArgument("--hiveconf").addArgument(db));
+		results = HiveHelper.execCommand(new CommandLine("hive").addArgument("-e").addArgument("DROP DATABASE bigtop_runtime_hive").addArgument("--hiveconf").addArgument(db));
 	}
 	
 	@AfterClass
 	public static void cleanup(){
-		results = HiveHelper.execCommand(new CommandLine("hive").addArgument("-e").addArgument("DROP DATABASE odpi_runtime_hive").addArgument("--hiveconf").addArgument(db));
+		results = HiveHelper.execCommand(new CommandLine("hive").addArgument("-e").addArgument("DROP DATABASE bigtop_runtime_hive").addArgument("--hiveconf").addArgument(db));
 		results = HiveHelper.execCommand(new CommandLine("/bin/sh").addArgument("-c").addArgument("rm -rf hive-f*.sql", false));
 		results = HiveHelper.execCommand(new CommandLine("/bin/sh").addArgument("-c").addArgument("rm -rf hive-init*.sql", false));
 		results = HiveHelper.execCommand(new CommandLine("/bin/sh").addArgument("-c").addArgument("rm -rf hive-define.sql", false));

http://git-wip-us.apache.org/repos/asf/bigtop/blob/0f51fb32/bigtop-tests/smoke-tests/odpi-runtime/src/test/java/org/odpi/specs/runtime/hive/TestHCatalog.java
----------------------------------------------------------------------
diff --git a/bigtop-tests/smoke-tests/odpi-runtime/src/test/java/org/odpi/specs/runtime/hive/TestHCatalog.java b/bigtop-tests/smoke-tests/odpi-runtime/src/test/java/org/odpi/specs/runtime/hive/TestHCatalog.java
index e8c4763..8bf7141 100644
--- a/bigtop-tests/smoke-tests/odpi-runtime/src/test/java/org/odpi/specs/runtime/hive/TestHCatalog.java
+++ b/bigtop-tests/smoke-tests/odpi-runtime/src/test/java/org/odpi/specs/runtime/hive/TestHCatalog.java
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.odpi.specs.runtime.hive;
+package org.apache.bigtop.itest.hive;
 
 import org.apache.commons.exec.CommandLine;
 import org.apache.commons.logging.Log;
@@ -51,8 +51,8 @@ import java.util.Random;
 
 
 public class TestHCatalog {
-  private static final String JOBJAR = "odpi.test.hive.hcat.job.jar";
-  private static final String HCATCORE = "odpi.test.hive.hcat.core.jar";
+  private static final String JOBJAR = "bigtop.test.hive.hcat.job.jar";
+  private static final String HCATCORE = "bigtop.test.hive.hcat.core.jar";
 
   private static final Log LOG = LogFactory.getLog(TestHCatalog.class.getName());
 
@@ -92,7 +92,7 @@ public class TestHCatalog {
   public void hcatInputFormatOutputFormat() throws TException, IOException, ClassNotFoundException,
       InterruptedException, URISyntaxException {
     // Create a table to write to
-    final String inputTable = "odpi_hcat_input_table_" + rand.nextInt(Integer.MAX_VALUE);
+    final String inputTable = "bigtop_hcat_input_table_" + rand.nextInt(Integer.MAX_VALUE);
     SerDeInfo serde = new SerDeInfo("default_serde",
         conf.getVar(HiveConf.ConfVars.HIVEDEFAULTSERDE), new HashMap<String, String>());
     FieldSchema schema = new FieldSchema("line", "string", "");
@@ -106,7 +106,7 @@ public class TestHCatalog {
         new HashMap<String, String>(), null, null, TableType.MANAGED_TABLE.toString());
     client.createTable(table);
 
-    final String outputTable = "odpi_hcat_output_table_" + rand.nextInt(Integer.MAX_VALUE);
+    final String outputTable = "bigtop_hcat_output_table_" + rand.nextInt(Integer.MAX_VALUE);
     sd = new StorageDescriptor(Arrays.asList(
           new FieldSchema("word", "string", ""),
           new FieldSchema("count", "int", "")),

http://git-wip-us.apache.org/repos/asf/bigtop/blob/0f51fb32/bigtop-tests/smoke-tests/odpi-runtime/src/test/java/org/odpi/specs/runtime/hive/TestJdbc.java
----------------------------------------------------------------------
diff --git a/bigtop-tests/smoke-tests/odpi-runtime/src/test/java/org/odpi/specs/runtime/hive/TestJdbc.java b/bigtop-tests/smoke-tests/odpi-runtime/src/test/java/org/odpi/specs/runtime/hive/TestJdbc.java
index 6a99a17..a5a896a 100644
--- a/bigtop-tests/smoke-tests/odpi-runtime/src/test/java/org/odpi/specs/runtime/hive/TestJdbc.java
+++ b/bigtop-tests/smoke-tests/odpi-runtime/src/test/java/org/odpi/specs/runtime/hive/TestJdbc.java
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.odpi.specs.runtime.hive;
+package org.apache.bigtop.itest.hive;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -295,9 +295,9 @@ public class TestJdbc extends JdbcConnector {
     try (Statement stmt = conn.createStatement(ResultSet.TYPE_SCROLL_INSENSITIVE,
         ResultSet.CONCUR_READ_ONLY)) {
 
-      final String dbName = "odpi_jdbc_test_db";
+      final String dbName = "bigtop_jdbc_test_db";
 
-      final String tableName = "odpi_jdbc_test_table";
+      final String tableName = "bigtop_jdbc_test_table";
       stmt.execute("drop table if exists " + tableName);
 
       stmt.execute("drop database if exists " + dbName + " cascade");
@@ -345,7 +345,7 @@ public class TestJdbc extends JdbcConnector {
     try (Statement stmt = conn.createStatement()) {
       stmt.clearWarnings();
 
-      final String tableName = "odpi_jdbc_statement_test_table";
+      final String tableName = "bigtop_jdbc_statement_test_table";
 
       stmt.execute("drop table if exists " + tableName);
       stmt.execute("create table " + tableName + " (a int, b varchar(32))");
@@ -409,7 +409,7 @@ public class TestJdbc extends JdbcConnector {
 
   @Test
   public void preparedStmtAndResultSet() throws SQLException {
-    final String tableName = "odpi_jdbc_psars_test_table";
+    final String tableName = "bigtop_jdbc_psars_test_table";
     try (Statement stmt = conn.createStatement()) {
       stmt.execute("drop table if exists " + tableName);
       stmt.execute("create table " + tableName + " (bo boolean, ti tinyint, db double, fl float, " +

http://git-wip-us.apache.org/repos/asf/bigtop/blob/0f51fb32/bigtop-tests/smoke-tests/odpi-runtime/src/test/java/org/odpi/specs/runtime/hive/TestSql.java
----------------------------------------------------------------------
diff --git a/bigtop-tests/smoke-tests/odpi-runtime/src/test/java/org/odpi/specs/runtime/hive/TestSql.java b/bigtop-tests/smoke-tests/odpi-runtime/src/test/java/org/odpi/specs/runtime/hive/TestSql.java
index 99451d1..06af1da 100644
--- a/bigtop-tests/smoke-tests/odpi-runtime/src/test/java/org/odpi/specs/runtime/hive/TestSql.java
+++ b/bigtop-tests/smoke-tests/odpi-runtime/src/test/java/org/odpi/specs/runtime/hive/TestSql.java
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.odpi.specs.runtime.hive;
+package org.apache.bigtop.itest.hive;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -31,8 +31,8 @@ public class TestSql extends JdbcConnector {
 
   @Test
   public void db() throws SQLException {
-    final String db1 = "odpi_sql_db1";
-    final String db2 = "odpi_sql_db2";
+    final String db1 = "bigtop_sql_db1";
+    final String db2 = "bigtop_sql_db2";
     try (Statement stmt = conn.createStatement()) {
       stmt.execute("drop database if exists " + db1 + " cascade");
 
@@ -56,11 +56,11 @@ public class TestSql extends JdbcConnector {
 
   @Test
   public void table() throws SQLException {
-    final String table1 = "odpi_sql_table1";
-    final String table2 = "odpi_sql_table2";
-    final String table3 = "odpi_sql_table3";
-    final String table4 = "odpi_sql_table4";
-    final String table5 = "odpi_sql_table5";
+    final String table1 = "bigtop_sql_table1";
+    final String table2 = "bigtop_sql_table2";
+    final String table3 = "bigtop_sql_table3";
+    final String table4 = "bigtop_sql_table4";
+    final String table5 = "bigtop_sql_table5";
 
     try (Statement stmt = conn.createStatement()) {
       stmt.execute("drop table if exists " + table1);
@@ -126,7 +126,7 @@ public class TestSql extends JdbcConnector {
 
   @Test
   public void partitionedTable() throws SQLException {
-    final String table1 = "odpi_sql_ptable1";
+    final String table1 = "bigtop_sql_ptable1";
     try (Statement stmt = conn.createStatement()) {
       stmt.execute("drop table if exists " + table1);
 
@@ -157,9 +157,9 @@ public class TestSql extends JdbcConnector {
 
   @Test
   public void view() throws SQLException {
-    final String table1 = "odpi_sql_vtable1";
-    final String view1 = "odpi_sql_view1";
-    final String view2 = "odpi_sql_view2";
+    final String table1 = "bigtop_sql_vtable1";
+    final String view1 = "bigtop_sql_view1";
+    final String view2 = "bigtop_sql_view2";
     try (Statement stmt = conn.createStatement()) {
       stmt.execute("drop table if exists " + table1);
       stmt.execute("drop view if exists " + view1);
@@ -185,8 +185,8 @@ public class TestSql extends JdbcConnector {
 
   @Test
   public void function() throws SQLException {
-    final String func1 = "odpi_sql_func1";
-    final String func2 = "odpi_sql_func2";
+    final String func1 = "bigtop_sql_func1";
+    final String func2 = "bigtop_sql_func2";
     try (Statement stmt = conn.createStatement()) {
       stmt.execute("create temporary function " + func1 +
           " as 'org.apache.hadoop.hive.ql.udf.UDFToInteger'");
@@ -208,8 +208,8 @@ public class TestSql extends JdbcConnector {
   // test machine has access to HDFS and thus the ability to upload a file.
   @Test
   public void insert() throws SQLException {
-    final String table1 = "odpi_insert_table1";
-    final String table2 = "odpi_insert_table2";
+    final String table1 = "bigtop_insert_table1";
+    final String table2 = "bigtop_insert_table2";
     try (Statement stmt = conn.createStatement()) {
       stmt.execute("drop table if exists " + table1);
       stmt.execute("create table " + table1 +
@@ -269,7 +269,7 @@ public class TestSql extends JdbcConnector {
   // This tests CTEs
   @Test
   public void cte() throws SQLException {
-    final String table1 = "odpi_cte_table1";
+    final String table1 = "bigtop_cte_table1";
     try (Statement stmt = conn.createStatement()) {
       stmt.execute("drop table if exists " + table1);
       stmt.execute("create table " + table1 + "(c1 int, c2 varchar(32))");
@@ -284,7 +284,7 @@ public class TestSql extends JdbcConnector {
 
   @Test
   public void select() throws SQLException {
-    final String[] tables = {"odpi_select_table1", "odpi_select_table2"};
+    final String[] tables = {"bigtop_select_table1", "bigtop_select_table2"};
     try (Statement stmt = conn.createStatement()) {
       for (int i = 0; i < tables.length; i++) {
         stmt.execute("drop table if exists " + tables[i]);

http://git-wip-us.apache.org/repos/asf/bigtop/blob/0f51fb32/bigtop-tests/smoke-tests/odpi-runtime/src/test/java/org/odpi/specs/runtime/hive/TestThrift.java
----------------------------------------------------------------------
diff --git a/bigtop-tests/smoke-tests/odpi-runtime/src/test/java/org/odpi/specs/runtime/hive/TestThrift.java b/bigtop-tests/smoke-tests/odpi-runtime/src/test/java/org/odpi/specs/runtime/hive/TestThrift.java
index 58c6595..f54b7e5 100644
--- a/bigtop-tests/smoke-tests/odpi-runtime/src/test/java/org/odpi/specs/runtime/hive/TestThrift.java
+++ b/bigtop-tests/smoke-tests/odpi-runtime/src/test/java/org/odpi/specs/runtime/hive/TestThrift.java
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.odpi.specs.runtime.hive;
+package org.apache.bigtop.itest.hive;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -71,7 +71,7 @@ public class TestThrift {
 
   @Test
   public void db() throws TException {
-    final String dbName = "odpi_thrift_db_" + rand.nextInt(Integer.MAX_VALUE);
+    final String dbName = "bigtop_thrift_db_" + rand.nextInt(Integer.MAX_VALUE);
 
     Database db = new Database(dbName, "a db", null, new HashMap<String, String>());
     client.createDatabase(db);
@@ -80,7 +80,7 @@ public class TestThrift {
     db = new Database(db);
     db.getParameters().put("a", "b");
     client.alterDatabase(dbName, db);
-    List<String> alldbs = client.getDatabases("odpi_*");
+    List<String> alldbs = client.getDatabases("bigtop_*");
     Assert.assertNotNull(alldbs);
     Assert.assertTrue(alldbs.size() > 0);
     alldbs = client.getAllDatabases();
@@ -93,7 +93,7 @@ public class TestThrift {
 
   @Test
   public void nonPartitionedTable() throws TException {
-    final String tableName = "odpi_thrift_table_" + rand.nextInt(Integer.MAX_VALUE);
+    final String tableName = "bigtop_thrift_table_" + rand.nextInt(Integer.MAX_VALUE);
 
     // I don't test every operation related to tables, but only those that are frequently used.
     SerDeInfo serde = new SerDeInfo("default_serde",
@@ -115,7 +115,7 @@ public class TestThrift {
     Assert.assertNotNull(tables);
     Assert.assertEquals(1, tables.size());
 
-    List<String> tableNames = client.getTables("default", "odpi_*");
+    List<String> tableNames = client.getTables("default", "bigtop_*");
     Assert.assertNotNull(tableNames);
     Assert.assertTrue(tableNames.size() >= 1);
 
@@ -143,7 +143,7 @@ public class TestThrift {
 
   @Test
   public void partitionedTable() throws TException {
-    final String tableName = "odpi_thrift_partitioned_table_" + rand.nextInt(Integer.MAX_VALUE);
+    final String tableName = "bigtop_thrift_partitioned_table_" + rand.nextInt(Integer.MAX_VALUE);
 
     // I don't test every operation related to tables, but only those that are frequently used.
     SerDeInfo serde = new SerDeInfo("default_serde",
diff --git a/bigtop-tests/smoke-tests/odpi-runtime/src/main/resources/api-examiner-prep.sh b/bigtop-tests/smoke-tests/odpi-runtime/src/main/resources/api-examiner-prep.sh
index d062f17..db899c8 100755
--- a/bigtop-tests/smoke-tests/odpi-runtime/src/main/resources/api-examiner-prep.sh
+++ b/bigtop-tests/smoke-tests/odpi-runtime/src/main/resources/api-examiner-prep.sh
@@ -40,7 +40,7 @@
 # $BIGTOP_HOME/bigtop-tests/spec-tests/runtime/src/main/resources/api-examiner.sh -j $HADOOP_HOME/share/hadoop/common/hadoop-common-2.7.3.jar -p $BIGTOP_HOME/bigtop-tests/spec-tests/runtime/src/test/resources
 #
 # The resulting reports should be committed to git.  This script only needs
 # to be run once per ODPi release.
 ############################################################################
 
 
@@ -66,5 +66,5 @@ do
     CLASSPATH=$CLASSPATH:$jar
 done
 
-java -cp $CLASSPATH org.odpi.specs.runtime.hadoop.ApiExaminer $@
+java -cp $CLASSPATH org.apache.bigtop.itest.hadoop.api.ApiExaminer $@
 

http://git-wip-us.apache.org/repos/asf/bigtop/blob/0f51fb32/bigtop-tests/smoke-tests/odpi-runtime/src/test/groovy/org/odpi/specs/runtime/TestSpecsRuntime.groovy
----------------------------------------------------------------------
@@ -40,7 +40,7 @@
 #
 # The resulting reports should be committed to git.  This script only needs
-# to be run once per ODPi release.
+# to be run once per Bigtop release.
 ############################################################################
 